@@ -3,14 +3,17 @@
     var mtable = { props: ['url', 'filter', 'order', 'editable', 'create', 'deletable', 'render'], data: null, methods: {}};
     
     mtable.data = function() {        
-        var data = {mtUrl: this.url,
+        var data = {url: this.url,
                     busy: false,
-                    mtFilter: this.filter || '',
-                    mtOrder: this.order ||  '',
+                    filter: this.filter || '',
+                    order: this.order ||  '',
                     errors: {},
                     item: null,
                     message: '',
-                    table: { model: [], items: [], count: 0}};
+                    reference_options: {},
+                    table: { model: [], items: [], count: 0},
+		    string_values: {}
+		   };
         mtable.methods.load.call(data);
         return data;
     };
@@ -21,9 +24,9 @@
     mtable.methods.load = function() {
         let self = this;
         let length = this.table.items.length;
-        let url = this.mtUrl + '?@limit=20';
+        let url = this.url + '?@limit=20';
         if (length) url+='&@offset='+length; else url+='&@model=true';
-        let filters = self.mtFilter.split(' and ').filter((f)=>{return f.trim() != ''});
+        let filters = self.filter.split(' and ').filter((f)=>{return f.trim() != ''});
         filters = filters.filter((f)=>{return f.trim();}).map((f)=>{                
                 let parts = (f
                              .replace(/ equals? /,'==')
@@ -47,7 +50,7 @@
                         '=' + parts[parts.length-1].replace(/^ /,''));
             });
         if (filters.length) url += '&'+filters.join('&');
-        if (self.mtOrder) url += '&@order='+self.mtOrder;
+        if (self.order) url += '&@order='+self.order;
         self.busy = true;
         axios.get(url).then(function (res) {
                 self.busy = false;
@@ -57,9 +60,9 @@
     };
     
     mtable.methods.reorder = function (field) {
-        if (this.mtOrder == '~' + field.name) this.mtOrder = null;
-        else if (this.mtOrder == field.name) this.mtOrder = '~'+field.name;
-        else this.mtOrder = field.name;
+        if (this.order == '~' + field.name) this.order = null;
+        else if (this.order == field.name) this.order = '~'+field.name;
+        else this.order = field.name;
         this.table.items = [];
         this.load();
     };
@@ -72,17 +75,67 @@
 
     mtable.methods.open_create = function () {
         this.item = {};
-        for(var field in this.model) this.item[field.name] = field.default||'';
+        this.prepare_fields(this.item);
     };
-    
+
     mtable.methods.open_edit = function (item) {
         this.item = {};
         this.item = item;
+        this.prepare_fields(this.item);
     };
-    
+
+    mtable.methods.l2s = function(list) {
+	return (list||[]).map(function(x){return ''+x}).join(', ');
+    };
+
+    mtable.methods.s2l = function(string, is_list_integer) {
+        var v = string;
+        v = v && v.split(',').map(function(x){return x.trim();}) || [];
+        if (is_list_integer) v = v.map(function(x){return parseInt(x)})
+        return v;
+    };
+
+    mtable.methods.prepare_fields = function(item){
+        let self = this;
+        for(var field of this.table.model){
+            console.log(field.name);
+	    if(field.type == "list:string" || field.type == "list:integer" || field.type.substr(0,14) == "list:reference"){
+		self.string_values[field.name] = mtable.methods.l2s(item[field.name]);
+		console.log(self.string_values[field.name]);
+	    } else if (field.type == "datetime") {
+		output = field.default != null ? field.default : '';
+                output = output.split('.')[0];
+		Vue.set(this.item, field.name, output);
+	    } else if(field.type == "reference"){
+                if (!(field.references in this.reference_options)){
+                    Vue.set(this.reference_options, field.references, []);
+                    let reference_table_url = self.url.split('/');                    
+                    reference_table_url.pop()
+                    reference_table_url.push(field.references)
+                    reference_table_url = reference_table_url.join('/') + '?@options_list=true';
+                    axios.get(reference_table_url).then(function (res) {
+                        let url_components = res.config.url.split('?')[0].split('/');
+                        self.reference_options[url_components[url_components.length - 1 ]] = res.data.items;
+                     });
+                    
+                }
+            }
+        }
+    }
+
+    mtable.methods.parse_and_validate_json = function(event){
+        try {
+            event.target.style.borderColor = "";
+            return JSON.parse(event.target.value);
+        }
+        catch (error) {
+            event.target.style.borderColor = "#ff0000";
+        }
+    }
+
     mtable.methods.trash = function (item) {
         if (window.confirm("Really delete record?")) {
-            let url = this.mtUrl + '/' + item.id;            
+            let url = this.url + '/' + item.id;            
             this.table.items = this.table.items.filter((i)=>{return i.id != item.id;});
             axios.delete(url);
             if (item==this.item) this.item = null;
@@ -90,8 +143,14 @@
     };
     
     mtable.methods.save = function (item) {
-        let url = this.mtUrl;
+        let url = this.url;
         self.busy = true;
+	for(var field of this.table.model) {
+	    var is_list_integer = field.type == "list:integer" || field.type.substr(0,14) == "list:reference";
+	    if(field.type == "list:string" || is_list_integer) {
+		item[field.name] = mtable.methods.s2l(this.string_values[field.name], is_list_integer);
+	    }
+	}
         if (item.id) {
             url += '/' + item.id;
             axios.put(url, item).then(mtable.handle_response('put', this),
@@ -111,16 +170,12 @@
                 console.log(data);
                 mtable.methods.load.call(data);
             }
-            console.log('a');
-            console.log(res);
             if (res.data.status == 'success') {
                 data.clear();
             } else {
-                console.log('b')
                 data.errors = res.data.errors;
                 data.message = res.data.message;
             }
-            console.log('c');
         };
     };
 
@@ -152,6 +207,8 @@
         window.location = window.location.href.split('?')[0]+'?'+source;
     };
 
+
+
     var scripts = document.getElementsByTagName('script');
     var src = scripts[scripts.length-1].src;
     var path = src.substr(0, src.length-3) + '.html';
